/*
 * $Id: strconv.h,v 1.1 2009-11-16 09:13:04 hito Exp $
 */

char *sjis_to_utf8(const char *src);
char *utf8_to_sjis(const char *src);
gchar *ascii2greece(const gchar *src);
